@@ -1,5 +1,5 @@
-test_that("test use_favicon",{
-  with_dir(pkg,{
+test_that("test use_favicon", {
+  with_dir(pkg, {
     use_favicon()
     expect_true(file.exists("inst/app/www/favicon.ico"))
     lapply(
@@ -9,17 +9,19 @@ test_that("test use_favicon",{
         "test.gif",
         "test.tiff"
       ),
-      function(.x) {expect_error(
-        use_favicon(path = .x)
-      )}
+      function(.x) {
+        expect_error(
+          use_favicon(path = .x)
+        )
+      }
     )
     golem::remove_favicon()
     expect_false(file.exists("inst/app/www/favicon.ico"))
   })
 })
 
-test_that("test use_favicon online",{
-  with_dir(pkg,{
+test_that("test use_favicon online", {
+  with_dir(pkg, {
     skip_on_cran()
     golem::remove_favicon()
     expect_false(file.exists("inst/app/www/favicon.ico"))
@@ -27,23 +29,22 @@ test_that("test use_favicon online",{
     expect_true(file.exists("inst/app/www/favicon.ico"))
   })
 })
-test_that("test use_favicon online fail",{
-  with_dir(pkg,{
+test_that("test use_favicon online fail", {
+  with_dir(pkg, {
     golem::remove_favicon()
     expect_false(file.exists("inst/app/www/favicon.ico"))
-    if (getRversion() >= "3.5"){
-    expect_error(use_favicon(path = "https://fr.wikipedia.org//static/favicon/dontexist.ico"))
+    if (getRversion() >= "3.5") {
+      expect_error(use_favicon(path = "https://fr.wikipedia.org//static/favicon/dontexist.ico"))
     }
     expect_false(file.exists("inst/app/www/favicon.ico"))
   })
 })
 
-test_that("test favicon",{
-  with_dir(pkg,{
-    expect_is(
-      favicon("jean","jean"),
+test_that("test favicon", {
+  with_dir(pkg, {
+    expect_s3_class(
+      favicon("jean", "jean"),
       "shiny.tag"
     )
   })
 })
-
